pub struct ShapeInference;Implementations
Sourceimpl ShapeInference
impl ShapeInference
pub fn new() -> Self
Sourcepub fn infer_shapes_with_schema_extractor(
&self,
components: &HashMap<String, ComponentConfig>,
schema_extractor: &SchemaExtractor,
) -> Result<ShapeConfig, Error>
pub fn infer_shapes_with_schema_extractor( &self, components: &HashMap<String, ComponentConfig>, schema_extractor: &SchemaExtractor, ) -> Result<ShapeConfig, Error>
Compute overall shape configuration from components (enhanced with metadata-driven detection) Returns an error if components have insufficient tensor metadata
Sourcepub fn infer_shapes(
&self,
components: &HashMap<String, ComponentConfig>,
) -> Result<ShapeConfig, Error>
pub fn infer_shapes( &self, components: &HashMap<String, ComponentConfig>, ) -> Result<ShapeConfig, Error>
Compute overall shape configuration from components (legacy approach) Returns an error if components have insufficient tensor metadata
Sourcepub fn analyze_components(
&self,
components: &HashMap<String, ComponentConfig>,
) -> ComponentAnalysis
pub fn analyze_components( &self, components: &HashMap<String, ComponentConfig>, ) -> ComponentAnalysis
Analyze component characteristics for debugging